@@ -49,7 +49,8 @@ public:
     MainWindowPrivate()
         : m_activePart(0),
           m_bShellGUIActivated(false),
-          m_helpMenu(0)
+          m_helpMenu(0),
+          m_manageWindowTitle(true)
     {
     }
     ~MainWindowPrivate()
@@ -59,6 +60,7 @@ public:
     QPointer<Part> m_activePart;
     bool m_bShellGUIActivated;
     KHelpMenu *m_helpMenu;
+    bool m_manageWindowTitle;
 };
 }
 
@@ -96,10 +98,10 @@ void MainWindow::createGUI(Part *part)
 
         factory->removeClient(d->m_activePart);
 
-        disconnect(d->m_activePart, SIGNAL(setWindowCaption(QString)),
-                   this, SLOT(setCaption(QString)));
-        disconnect(d->m_activePart, SIGNAL(setStatusBarText(QString)),
-                   this, SLOT(slotSetStatusBarText(QString)));
+        disconnect(d->m_activePart.data(), &Part::setWindowCaption,
+                   this, static_cast<void (MainWindow::*)(const QString &)>(&MainWindow::setCaption));
+        disconnect(d->m_activePart.data(), &Part::setStatusBarText,
+                   this, &MainWindow::slotSetStatusBarText);
     }
 
     if (!d->m_bShellGUIActivated) {
@@ -110,10 +112,12 @@ void MainWindow::createGUI(Part *part)
 
     if (part) {
         // do this before sending the activate event
-        connect(part, SIGNAL(setWindowCaption(QString)),
-                this, SLOT(setCaption(QString)));
-        connect(part, SIGNAL(setStatusBarText(QString)),
-                this, SLOT(slotSetStatusBarText(QString)));
+        if (d->m_manageWindowTitle) {
+            connect(part, &Part::setWindowCaption,
+                    this, static_cast<void (MainWindow::*)(const QString &)>(&MainWindow::setCaption));
+        }
+        connect(part, &Part::setStatusBarText,
+                this, &MainWindow::slotSetStatusBarText);
 
         factory->addClient(part);
 
@@ -144,6 +148,7 @@ void MainWindow::createShellGUI(bool create)
             QAction *switchLanguageAction = d->m_helpMenu->action(KHelpMenu::menuSwitchLanguage);
             QAction *aboutAppAction = d->m_helpMenu->action(KHelpMenu::menuAboutApp);
             QAction *aboutKdeAction = d->m_helpMenu->action(KHelpMenu::menuAboutKDE);
+            QAction *donateAction = d->m_helpMenu->action(KHelpMenu::menuDonate);
 
             if (helpContentsAction) {
                 actions->addAction(helpContentsAction->objectName(), helpContentsAction);
@@ -163,6 +168,9 @@ void MainWindow::createShellGUI(bool create)
             if (aboutKdeAction) {
                 actions->addAction(aboutKdeAction->objectName(), aboutKdeAction);
             }
+            if (donateAction) {
+                actions->addAction(donateAction->objectName(), donateAction);
+            }
         }
 
         QString f = xmlFile();
@@ -178,6 +186,8 @@ void MainWindow::createShellGUI(bool create)
         QApplication::sendEvent(this, &ev);
 
         guiFactory()->addClient(this);
+
+        checkAmbiguousShortcuts();
     } else {
         GUIActivateEvent ev(false);
         QApplication::sendEvent(this, &ev);
@@ -186,6 +196,11 @@ void MainWindow::createShellGUI(bool create)
     }
 }
 
+void KParts::MainWindow::setWindowTitleHandling(bool enabled)
+{
+    d->m_manageWindowTitle = enabled;
+}
+
 void KParts::MainWindow::saveNewToolbarConfig()
 {
     createGUI(d->m_activePart);
